@@ -1,6 +1,6 @@
 /*
  * error.c
- * libansilove 1.2.3
+ * libansilove 1.2.8
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -29,6 +29,9 @@ ansilove_error(struct ansilove_ctx *ctx)
 	case ANSILOVE_MEMORY_ERROR:
 		return "Memory allocation error.";
 		break;
+	case ANSILOVE_RANGE_ERROR:
+		return "Value out of allowed range.";
+		break;
 	case ANSILOVE_FILE_READ_ERROR:
 		return "Error reading file.";
 		break;
