@@ -1,6 +1,6 @@
 /*
  * loadfile.c
- * libansilove 1.2.3
+ * libansilove 1.2.8
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -18,7 +18,7 @@
 #include "ansilove.h"
 
 int
-ansilove_loadfile(struct ansilove_ctx *ctx, char *input)
+ansilove_loadfile(struct ansilove_ctx *ctx, const char *input)
 {
 	int fd;
 	struct stat st;
