@@ -1,6 +1,6 @@
 /*
  * output.c
- * libansilove 1.2.3
+ * libansilove 1.2.8
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -37,15 +37,20 @@ output(struct ansilove_ctx *ctx, struct ansilove_options *options,
 
 	/* Handle resizing */
 	if (options->scale_factor) {
+		if (options->scale_factor < 2 || options->scale_factor > 8) {
+			ctx->error = ANSILOVE_RANGE_ERROR;
+			return -1;
+		}
+
+		uint32_t width, height;
 		gdImagePtr retina;
 
-		if gdImageTrueColor(source) {
-			retina = gdImageCreateTrueColor(source->sx *
-			     options->scale_factor, source->sy * options->scale_factor);
-		} else {
-			retina = gdImageCreate(source->sx *
-			     options->scale_factor, source->sy * options->scale_factor);
-		}
+		width = source->sx * options->scale_factor;
+		height = source->sy * options->scale_factor;
+
+		retina = gdImageTrueColor(source) ?
+			gdImageCreateTrueColor(width, height) :
+			gdImageCreate(width, height);
 
 		if (!retina) {
 			ctx->error = ANSILOVE_GD_ERROR;
