@@ -1,6 +1,6 @@
 /*
  * savefile.c
- * libansilove 1.2.3
+ * libansilove 1.2.8
  * https://www.ansilove.org
  *
  * Copyright (c) 2011-2020 Stefan Vogt, Brian Cassidy, and Frederic Cambus
@@ -14,7 +14,7 @@
 #include "ansilove.h"
 
 int
-ansilove_savefile(struct ansilove_ctx *ctx, char *output)
+ansilove_savefile(struct ansilove_ctx *ctx, const char *output)
 {
 	size_t rw;
 
